package
Version:
v0.0.0-...-e4a9173
Opens a new window with list of versions in this module.
Published: Oct 25, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Queue interface {
Push(v interface{})
Pop() interface{}
Peek() interface{}
Len() int
}
Queue 通用队列
Source Files
¶
Click to show internal directories.
Click to hide internal directories.